package cn.dg32z.lon.commands.sub;

import cn.dg32z.libs.org.jetbrains.annotations.NotNull;
import cn.dg32z.lon.PluginLoader;
import cn.dg32z.lon.commands.AbstractCommand;
import cn.dg32z.lon.utils.crash.CrashUtil;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;
import org.bukkit.Bukkit;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

/* loaded from: cn_dg32z_lon_commands_sub.jar:cn/dg32z/lon/commands/sub/Crash.class */
public final class Crash extends AbstractCommand {
    public Crash() {
        super("crash player", "lonac.commands.crash", false);
    }

    public void execute(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
        if (validateInput(sender, args)) {
            Player target = Bukkit.getPlayer(args[0]);
            String crashType = args.length > 1 ? args[1] : "explosion";
            if (processCrash(target, crashType)) {
                sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n(target, "commands.crash.message"));
            } else {
                sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.crash.invalid-type"));
            }
        }
    }

    private boolean processCrash(Player target, String type) {
        String lowerCase = type.toLowerCase();
        boolean z = -1;
        switch (lowerCase.hashCode()) {
            case -1600502750:
                if (lowerCase.equals("posandlook")) {
                    z = true;
                    break;
                }
                break;
            case -1298275357:
                if (lowerCase.equals("entity")) {
                    z = 3;
                    break;
                }
                break;
            case -147687043:
                if (lowerCase.equals("invalidparticle")) {
                    z = 2;
                    break;
                }
                break;
            case 108864:
                if (lowerCase.equals("nbt")) {
                    z = 4;
                    break;
                }
                break;
            case 333722389:
                if (lowerCase.equals("explosion")) {
                    z = false;
                    break;
                }
                break;
        }
        switch (z) {
            case false:
                CrashUtil.sendExplosion(target);
                return true;
            case true:
                CrashUtil.sendInvalidPosition(target);
                return true;
            case true:
                CrashUtil.sendInvalidParticle(target);
                return true;
            case true:
                CrashUtil.spawnArmorStands(target, 50);
                return true;
            case true:
                CrashUtil.sendCorruptNBT(target);
                return true;
            default:
                return true;
        }
    }

    public List<String> tabCompleter(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
        if (args.length == 1) {
            return (List) Bukkit.getOnlinePlayers().stream().map((v0) -> {
                return v0.getName();
            }).filter(n -> {
                return n.startsWith(args[0].toLowerCase());
            }).collect(Collectors.toList());
        }
        return args.length == 2 ? Arrays.asList("explosion", "posandlook", "invalidparticle", "entity", "nbt") : Collections.emptyList();
    }

    private boolean validateInput(CommandSender sender, String[] args) {
        if (args.length < 1) {
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.crash.usage"));
            return false;
        }
        Player target = Bukkit.getPlayer(args[0]);
        if (target == null) {
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("not-found").replace("%player%", args[0]));
            return false;
        }
        if (target == sender) {
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("not-my-self"));
            return false;
        }
        return true;
    }
}
